#! /usr/bin/perl
=head1 NAME

mibtoo.pl

=head1 SYNOPSIS

mibtoo.pl <file.csv>

Process the file and generate output in the output directory.

--help for more help

=head1 OPTIONS

=over 4

=item -i --id <idnum>

The unit id number to write the sysex to. Must be form 1 to 16. Defaults to 1

=item -h -? --help

Print help

=back

=head1 DESCRIPTION

Output the text configuration as sysex messages in a binary format
suitable for piping to a snd/midiCxDy

=back

=cut

use strict;
use Getopt::Long;

my $idParam = "1";
my $help = 0;

Getopt::Long::Configure ("bundling");
GetOptions(
	"i|id=s" => \$idParam
	, "h|help" => sub { $help = 2 }
);

if ( $help > 0 )
{
	print <<EOF;

EOF
}

die "id must be from 1 to 16" if ( $idParam < 1 || $idParam > 16 );

my $lo = 0;
my $hi = 0;
# this is for a BCF2000
my $unitType = "\x14\x20";

# this is for a BCR2000
#my $unitType = "\x15\x20";

my $id = sprintf ( "%2s", $idParam );

while (<>)
{
	my $line = $_;
	chomp $line;
	
	# ignore comments
	next if $line =~ m/^\S*#/;
	
	# add the prefix
	my $prefix = "\xf0\x00$id\x01$unitType";
	
	# add the ordinal of the sysex message
	my $numbyte = chr($hi) . chr($lo);
	
	print $prefix, $numbyte, $line, "\xf7";

	# the bcf only understands 7 bit numbers (ie up to 7f not ff)
	++$lo;
	if ( $lo > 0x7f )
	{
		++$hi;
		$lo = 0;
	}
}
